import argparse
from . import addition, soustraction, multiplication, division

def main():
    parser = argparse.ArgumentParser(description="Petite calculatrice en ligne de commande")
    parser.add_argument("operation", choices=["add", "sub", "mul", "div"], help="Opération à effectuer")
    parser.add_argument("a", type=float, help="Premier nombre")
    parser.add_argument("b", type=float, help="Deuxième nombre")
    
    args = parser.parse_args()

    if args.operation == "add":
        result = addition(args.a, args.b)
    elif args.operation == "sub":
        result = soustraction(args.a, args.b)
    elif args.operation == "mul":
        result = multiplication(args.a, args.b)
    elif args.operation == "div":
        result = division(args.a, args.b)

    print(f"Résultat : {result}")



def addition(a, b):
    return a + b

def soustraction(a, b):
    return a - b

def multiplication(a, b):
    return a * b

def division(a, b):
    if b == 0:
        raise ValueError("Division par zéro interdite")
    return a / b



from setuptools import setup, find_packages

setup(
    name='django-calcul',
    version='0.3.1',
    packages=find_packages(),
    include_package_data=True,
    license='MIT',
    description='',
    long_description=open('README.md', encoding='utf-8').read(),
    long_description_content_type='text/markdown',
    author='Nicosidick',
    author_email='abou210traore@gmail.com',
    entry_points={
        'console_scripts': [
            'django-calcul = p1.cli:main',
        ],
    },
    classifiers=[
        'Programming Language :: Python :: 3',
        'Framework :: Django',
        'License :: OSI Approved :: MIT License',
    ],
    install_requires=[],
)